@@ -622,7 +622,8 @@ gui_image_chooser_new (gboolean is_save)
 		g_signal_connect (fsel, "update-preview",
 				  G_CALLBACK (update_preview_cb), NULL);
 		update_preview_cb (fsel);
-	}*/
+	}
+*/
 	return fsel;
 }
 
@@ -715,8 +716,7 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 		state->uri = NULL;
 		state->resolution = 150.0;
 		state->is_expanded = FALSE;
-/* Maemo 5: changed from GO_IMAGE_FORMAT_SVG to GO_IMAGE_FORMAT_JPG */
-		state->format = GO_IMAGE_FORMAT_JPG;
+		state->format = GO_IMAGE_FORMAT_SVG;
 		g_object_set_data_full (G_OBJECT (toplevel), key,
 					state, (GDestroyNotify) save_info_state_free);
 	}	       
@@ -734,8 +734,7 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 			GSList *l;
 			format_combo = go_gtk_builder_combo_box_init_text (gui, "format_combo");
 			for (l = supported_formats, i = 0; l != NULL; l = l->next, i++) {
-				/* Maemo 5 change */
-				format = GO_IMAGE_FORMAT_JPG;
+				format = GPOINTER_TO_UINT (l->data);
 				format_info = go_image_get_format_info (format);
 				gtk_combo_box_append_text (format_combo, _(format_info->desc));
 				if (format == state->format)
@@ -750,7 +749,10 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 
 		if (supported_formats != NULL && ret_format != NULL) {
 			widget = go_gtk_builder_get_widget (gui, "image_save_dialog_extra");
-			gtk_file_chooser_set_extra_widget (fsel, widget);
+			/* Maemo5 specific changes */
+			gtk_widget_show_all(widget);
+			gtk_box_pack_start (GTK_BOX (GTK_DIALOG (fsel)->vbox), widget, FALSE, TRUE, 6);
+			
 		}
 
 		/* Export setting expander */
@@ -786,8 +788,9 @@ go_gui_get_image_save_info (GtkWindow *toplevel, GSList *supported_formats,
 	if (format_combo) {
 		char *new_uri = NULL;
 
-		/* Maemo 5 change */
-		format = GO_IMAGE_FORMAT_JPG;
+		format = GPOINTER_TO_UINT (g_slist_nth_data
+			(supported_formats,
+			 gtk_combo_box_get_active (format_combo)));
 		format_info = go_image_get_format_info (format);
 		if (!go_url_check_extension (uri, format_info->ext, &new_uri) &&
 		    !go_gtk_query_yes_no (GTK_WINDOW (fsel), TRUE,
