@@ -322,10 +322,10 @@ gog_line_plot_class_init (GogPlot1_5dClass *gog_plot_1_5d_klass)
 	gobject_klass->get_property = gog_line_get_property;
 
 	g_object_class_install_property (gobject_klass, GOG_LINE_PROP_DEFAULT_STYLE_HAS_MARKERS,
-		g_param_spec_boolean ("default-style-has-markers", 
+		g_param_spec_boolean ("default-style-has-markers",
 			_("Default markers"),
 			_("Should the default style of a series include markers"),
-			TRUE, 
+			TRUE,
 			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	gog_klass->type_name	= gog_line_plot_type_name;
@@ -353,6 +353,85 @@ GSF_DYNAMIC_CLASS (GogLinePlot, gog_line_plot,
 
 /*****************************************************************************/
 
+static GogObjectClass *gog_area_plot_parent_klass;
+
+enum {
+	AREA_PROP_FILL_0,
+	AREA_PROP_FILL_BEFORE_GRID
+};
+
+static void
+gog_area_plot_set_property (GObject *obj, guint param_id,
+		     GValue const *value, GParamSpec *pspec)
+{
+	GogPlot *plot = GOG_PLOT (obj);
+	switch (param_id) {
+	case AREA_PROP_FILL_BEFORE_GRID:
+		plot->rendering_order = (g_value_get_boolean (value))?
+					 GOG_PLOT_RENDERING_BEFORE_GRID:
+					 GOG_PLOT_RENDERING_LAST;
+		gog_object_emit_changed (GOG_OBJECT (obj), FALSE);
+		break;
+	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		 break;
+	}
+}
+
+static void
+gog_area_plot_get_property (GObject *obj, guint param_id,
+		     GValue *value, GParamSpec *pspec)
+{
+	GogPlot *plot = GOG_PLOT (obj);
+
+	switch (param_id) {
+	case AREA_PROP_FILL_BEFORE_GRID:
+		g_value_set_boolean (value, plot->rendering_order == GOG_PLOT_RENDERING_BEFORE_GRID);
+		break;
+	default: G_OBJECT_WARN_INVALID_PROPERTY_ID (obj, param_id, pspec);
+		 break;
+	}
+}
+
+#ifdef GOFFICE_WITH_GTK
+static void
+display_before_grid_cb (GtkToggleButton *btn, GObject *obj)
+{
+	g_object_set (obj, "before-grid", gtk_toggle_button_get_active (btn), NULL);
+}
+#endif
+
+static void
+gog_area_plot_populate_editor (GogObject *obj,
+			     GOEditor *editor,
+                             GogDataAllocator *dalloc,
+                             GOCmdContext *cc)
+{
+#ifdef GOFFICE_WITH_GTK
+	GtkBuilder *gui;
+	char const *dir;
+	char *path;
+
+	dir = go_plugin_get_dir_name (go_plugins_get_plugin_by_id ("GOffice_plot_barcol"));
+	path = g_build_filename (dir, "gog-area-prefs.ui", NULL);
+	gui = go_gtk_builder_new (path, GETTEXT_PACKAGE, cc);
+	g_free (path);
+
+	if (gui != NULL) {
+		GtkWidget *w = go_gtk_builder_get_widget (gui, "before-grid");
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w),
+				(GOG_PLOT (obj))->rendering_order == GOG_PLOT_RENDERING_BEFORE_GRID);
+		g_signal_connect (G_OBJECT (w),
+			"toggled",
+			G_CALLBACK (display_before_grid_cb), obj);
+		w = go_gtk_builder_get_widget (gui, "gog-area-prefs");
+		go_editor_add_page (editor, w, _("Properties"));
+		g_object_unref (gui);
+	}
+
+#endif
+	gog_area_plot_parent_klass->populate_editor (obj, editor, dalloc, cc);
+};
+
 static char const *
 gog_area_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 {
@@ -364,20 +443,32 @@ gog_area_plot_type_name (G_GNUC_UNUSED GogObject const *item)
 }
 
 static void
-gog_area_plot_class_init (GogObjectClass *gog_klass)
+gog_area_plot_class_init (GObjectClass *gobject_klass)
 {
-	GogPlotClass *plot_klass = (GogPlotClass *) gog_klass;
+	GogObjectClass *gog_klass = (GogObjectClass *) gobject_klass;
+	GogPlotClass   *plot_klass = (GogPlotClass *) gobject_klass;
+	gog_area_plot_parent_klass = g_type_class_peek_parent (gobject_klass);
+
+	gobject_klass->set_property = gog_area_plot_set_property;
+	gobject_klass->get_property = gog_area_plot_get_property;
+	g_object_class_install_property (gobject_klass, AREA_PROP_FILL_BEFORE_GRID,
+		g_param_spec_boolean ("before-grid",
+			_("Displayed under the grids"),
+			_("Should the plot be displayed before the grids"),
+			FALSE,
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GO_PARAM_PERSISTENT));
 
 	plot_klass->desc.series.style_fields = GO_STYLE_OUTLINE | GO_STYLE_FILL;
 	plot_klass->series_type = gog_series1_5d_get_type ();
 
+	gog_klass->populate_editor = gog_area_plot_populate_editor;
 	gog_klass->type_name	= gog_area_plot_type_name;
 }
 
 static void
 gog_area_plot_init (GogPlot *plot)
 {
-	plot->render_before_axes = TRUE;
+	plot->rendering_order = GOG_PLOT_RENDERING_BEFORE_AXIS;
 	GOG_PLOT1_5D (plot)->support_drop_lines = TRUE;
 }
 
@@ -443,28 +534,28 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 		return;
 
 	area = gog_chart_view_get_plot_area (view->parent);
-	chart_map = gog_chart_map_new (chart, area, 
-				       GOG_PLOT (model)->axis[GOG_AXIS_X], 
+	chart_map = gog_chart_map_new (chart, area,
+				       GOG_PLOT (model)->axis[GOG_AXIS_X],
 				       GOG_PLOT (model)->axis[GOG_AXIS_Y],
 				       NULL, FALSE);
 	if (!gog_chart_map_is_valid (chart_map)) {
 		gog_chart_map_free (chart_map);
 		return;
 	}
-	
+
 	x_map = gog_chart_map_get_axis_map (chart_map, 0);
 	y_map = gog_chart_map_get_axis_map (chart_map, 1);
-	
+
 	/* Draw drop lines from point to axis start. See comment in
 	 * GogXYPlotView::render */
 
-	gog_axis_map_get_extents (y_map, &drop_lines_y_min, &drop_lines_y_max); 
+	gog_axis_map_get_extents (y_map, &drop_lines_y_min, &drop_lines_y_max);
 	drop_lines_y_min = gog_axis_map_to_view (y_map, drop_lines_y_min);
 	drop_lines_y_max = gog_axis_map_to_view (y_map, drop_lines_y_max);
 	gog_axis_map_get_extents (y_map, &y_bottom, &y_top);
 	y_bottom = gog_axis_map_to_view (y_map, y_bottom);
 	y_top = gog_axis_map_to_view (y_map, y_top);
-	y_zero = gog_axis_map_get_baseline (y_map); 
+	y_zero = gog_axis_map_get_baseline (y_map);
 
 	vals    = g_alloca (num_series * sizeof (double *));
 	error_data = g_alloca (num_series * sizeof (ErrorBarData *));
@@ -496,7 +587,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			points[i] = g_malloc (sizeof (Point) * (lengths[i]));
 
 		errors[i] = series->errors;
-		if (gog_error_bar_is_visible (series->errors)) 
+		if (gog_error_bar_is_visible (series->errors))
 			error_data[i] = g_malloc (sizeof (ErrorBarData) * lengths[i]);
 		else
 			error_data[i] = NULL;
@@ -544,7 +635,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			x = gog_axis_map_to_view (x_map, j + 1);
 			sum += value;
 
-			if (gog_error_bar_is_visible (errors[i])) 
+			if (gog_error_bar_is_visible (errors[i]))
 				error_data[i][j].x = j + 1;
 
 			switch (type) {
@@ -581,7 +672,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 					break;
 
 				case GOG_1_5D_AS_PERCENTAGE :
-					y = is_null ? 
+					y = is_null ?
 						y_zero :
 						(gog_axis_map_finite (y_map, sum) ?
 						 gog_axis_map_to_view (y_map, sum  / abs_sum) :
@@ -597,7 +688,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 						go_path_line_to (paths[i], x, y);
 					break;
 			}
-			if (!is_area_plot){ 
+			if (!is_area_plot){
 				points[i][j].x = x;
 				points[i][j].y = y;
 			}
@@ -677,15 +768,15 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 	for (i = 0; i < num_series; i++)
 		if (gog_error_bar_is_visible (errors[i]))
 			for (j = 0; j < lengths[i]; j++)
-				gog_error_bar_render (errors[i], view->renderer, x_map, y_map,
+				gog_error_bar_render (errors[i], view->renderer, chart_map,
 						      error_data[i][j].x, error_data[i][j].y,
-						      error_data[i][j].minus, error_data[i][j].plus, 
-						      FALSE);
+						      error_data[i][j].minus, error_data[i][j].plus,
+						      GOG_ERROR_BAR_DIRECTION_VERTICAL);
 
 	gog_renderer_pop_clip (view->renderer);
 
 	/*Now draw markers*/
-	if (!is_area_plot) { 
+	if (!is_area_plot) {
 		double x_margin_min, x_margin_max, y_margin_min, y_margin_max, margin;
 
 		margin = gog_renderer_line_size (view->renderer, 1.0);
@@ -705,8 +796,12 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 			for (j = 0; j < lengths[i]; j++) {
 				x = points[i][j].x;
 				y = points[i][j].y;
-				if (isnan (y))
+				if (isnan (y)) {
+					if ((overrides != NULL) &&
+						(GOG_SERIES_ELEMENT (overrides->data)->index == j))
+						overrides = overrides->next;
 					continue;
+				}
 				gse = NULL;
 				if ((overrides != NULL) &&
 					(GOG_SERIES_ELEMENT (overrides->data)->index == j)) {
@@ -717,7 +812,7 @@ gog_line_view_render (GogView *view, GogViewAllocation const *bbox)
 								GO_STYLED_OBJECT (gse)));
 				}
 				if (x_margin_min <= x && x <= x_margin_max &&
-				    y_margin_min <= y && y <= y_margin_max) 
+				    y_margin_min <= y && y <= y_margin_max)
 					gog_renderer_draw_marker (view->renderer, x, y);
 				if (gse)
 					gog_renderer_pop_style (view->renderer);
